# Changelog

All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/),
and this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).

## [Unreleased]

## [0.2.5](https://github.com/denehoffman/laddu/compare/laddu-python-v0.2.4...laddu-python-v0.2.5) - 2025-01-28

### Other

- update Cargo.toml dependencies

## [0.2.4](https://github.com/denehoffman/laddu/compare/laddu-python-v0.2.3...laddu-python-v0.2.4) - 2025-01-27

### Added

- allow for the use of `sum(list[Dataset])` in Python code

## [0.2.3](https://github.com/denehoffman/laddu/compare/laddu-python-v0.2.2...laddu-python-v0.2.3) - 2025-01-24

### Other

- updated the following local packages: laddu-core
